@@ -2,17 +2,19 @@
 
 import subprocess
 import sys
+from pathlib import Path
 
+from wpiformat.config import Config
 from wpiformat.task import BatchTask
 
 
 class PyFormat(BatchTask):
     @staticmethod
-    def should_process_file(config_file, name):
-        return name.endswith(".py")
+    def should_process_file(config_file: Config, filename: Path) -> bool:
+        return filename.suffix == ".py"
 
     @staticmethod
-    def run_batch(config_file, names):
+    def run_batch(config_file: Config, filenames: list[Path]) -> bool:
         try:
             args = [
                 sys.executable,
@@ -24,7 +26,7 @@ class PyFormat(BatchTask):
                 "--quiet",
                 "-i",
             ]
-            subprocess.run(args + names)
+            subprocess.run(args + filenames)
         except FileNotFoundError:
             print(
                 "error: autoflake not found in PATH. Is it installed?", file=sys.stderr
@@ -33,14 +35,14 @@ class PyFormat(BatchTask):
 
         try:
             args = [sys.executable, "-m", "black", "-q"]
-            subprocess.run(args + names)
+            subprocess.run(args + filenames)
         except FileNotFoundError:
             print("error: black not found in PATH. Is it installed?", file=sys.stderr)
             return False
 
         try:
             args = [sys.executable, "-m", "isort", "--profile", "black", "-q"]
-            subprocess.run(args + names)
+            subprocess.run(args + filenames)
         except FileNotFoundError:
             print("error: isort not found in PATH. Is it installed?", file=sys.stderr)
             return False
